from django.contrib import admin
from django.conf import settings

if hasattr(settings, 'DJANGO_UI_SHOW_MODEL_EXAMPLE_DYNAMIC'):
    from django_ui.forms import ModelExampleForm
    from django_ui.models import ModelExample


    class ModelExampleAdmin(admin.ModelAdmin):
        model = ModelExample
        form = ModelExampleForm

        list_display = ('name', 'occupation')


    admin.site.register(ModelExample, ModelExampleAdmin)

if hasattr(settings, 'USE_APP_THEME_UI_ADMIN'):
    from django_ui.models import ThemeUI
    from django_ui.forms import ThemeUIForm


    class SettingsUIAdmin(admin.ModelAdmin):
        model = ThemeUI
        form = ThemeUIForm
        list_display = ('name_theme', 'applied', 'site_name', 'title_window',)

        def save_model(self, request, obj, form, change):
            list_settings = ThemeUI.objects.all()
            for setting in list_settings:
                setting.apply = False
                setting.save()

            obj.save()


    admin.site.register(ThemeUI, SettingsUIAdmin)



# Generated by Django 3.1 on 2020-08-23 18:33

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ModelExample',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=30)),
                ('occupation', models.CharField(choices=[('study', 'Study'), ('work', 'Work')], max_length=100, verbose_name='Occupation')),
                ('study', models.CharField(blank=True, max_length=100, null=True, verbose_name='Name Institution')),
                ('semester', models.CharField(blank=True, max_length=100, null=True, verbose_name='Semester')),
                ('company', models.CharField(blank=True, max_length=100, null=True, verbose_name='Company')),
                ('position', models.CharField(blank=True, max_length=100, null=True, verbose_name='Position')),
                ('nick', models.CharField(blank=True, max_length=100, null=True, verbose_name='Add NickName?')),
                ('nickname', models.CharField(blank=True, max_length=100, null=True, verbose_name='Nick Name')),
            ],
            options={
                'verbose_name': 'Model Example',
                'verbose_name_plural': 'Model Example',
            },
        ),
        migrations.CreateModel(
            name='ThemeUI',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name_theme', models.CharField(default='', max_length=200)),
                ('applied', models.BooleanField(help_text='If you select this, the previously applied theme is inactivated, if there is none selected by default, the one from django remains')),
                ('title_window', models.CharField(max_length=200, default='')),
                ('site_name', models.CharField(max_length=200, default='')),
                ('body_color', models.CharField(blank=True, default='#333', max_length=20, null=True)),
                ('header_color', models.CharField(blank=True, default='#ffc', max_length=20, null=True)),
                ('header_bg_color', models.CharField(blank=True, default='#417690', max_length=20, null=True)),
                ('breadcrumbs_color', models.CharField(blank=True, default='#c4dce8', max_length=20, null=True)),
                ('breadcrumbs_bg_color', models.CharField(blank=True, default='#79aec8', max_length=20, null=True)),
                ('module_color', models.CharField(blank=True, default='#fff', max_length=20, null=True)),
                ('module_bg_color', models.CharField(blank=True, default='#79aec8', max_length=20, null=True)),
                ('sidebar_current_model_bg_color', models.CharField(blank=True, default='#ffc', max_length=20, null=True)),
                ('section_link_color', models.CharField(blank=True, default='#ffc', max_length=20, null=True)),
                ('link_color', models.CharField(blank=True, default='#447e9b', max_length=20, null=True)),
                ('link_hover_color', models.CharField(blank=True, default='#036', max_length=20, null=True)),
                ('section_link_visited_color', models.CharField(blank=True, default='#ffc', max_length=20, null=True)),
                ('sidebar_color', models.CharField(blank=True, default='#ffc', max_length=20, null=True)),
                ('content_related_bg_color', models.CharField(blank=True, default='#f8f8f8', max_length=20, null=True)),
                ('content_related_title_color', models.CharField(blank=True, default='#333', max_length=20, null=True)),
                ('content_related_sub_title_color', models.CharField(blank=True, default='#666', max_length=20, null=True)),
                ('quiet_color', models.CharField(blank=True, default='#999', max_length=20, null=True)),
                ('button_tools_color', models.CharField(blank=True, default='#fff', max_length=20, null=True)),
                ('button_tools_bg_color', models.CharField(blank=True, default='#999', max_length=20, null=True)),
                ('button_tools_hover_color', models.CharField(blank=True, default='#fff', max_length=20, null=True)),
                ('button_tools_hover_bg_color', models.CharField(blank=True, default='#417690', max_length=20, null=True)),
                ('th_color', models.CharField(blank=True, default='#666', max_length=20, null=True)),
                ('th_bg_color', models.CharField(blank=True, default='#f6f6f6', max_length=20, null=True)),
                ('tr_even_bg_color', models.CharField(blank=True, default='#f9f9f9', max_length=20, null=True)),
                ('paginator_color', models.CharField(blank=True, default='#666', max_length=20, null=True)),
                ('paginator_bg_color', models.CharField(blank=True, default='#fff', max_length=20, null=True)),
                ('paginator_border_color', models.CharField(blank=True, default='#eee', max_length=20, null=True)),
                ('submit_delete_button_color', models.CharField(blank=True, default='#fff', max_length=20, null=True)),
                ('submit_delete_button_bg_color', models.CharField(blank=True, default='#ba2121', max_length=20, null=True)),
                ('submit_delete_button_bg_hover_color', models.CharField(blank=True, default='#a41515', max_length=20, null=True)),
                ('submit_save_primary_color', models.CharField(blank=True, default='#fff', max_length=20, null=True)),
                ('submit_save_primary_bg_color', models.CharField(blank=True, default='#417690', max_length=20, null=True)),
                ('submit_save_primary_bg_hover_color', models.CharField(blank=True, default='#205067', max_length=20, null=True)),
                ('submit_save_secondary_color', models.CharField(blank=True, default='#fff', max_length=20, null=True)),
                ('submit_save_secondary_bg_color', models.CharField(blank=True, default='#79aec8', max_length=20, null=True)),
                ('submit_save_secondary_bg_hover_color', models.CharField(blank=True, default='#609ab6', max_length=20, null=True)),
                ('cancel_button_color', models.CharField(blank=True, default='#333', max_length=20, null=True)),
                ('cancel_button_bg_color', models.CharField(blank=True, default='#ddd', max_length=20, null=True)),
                ('cancel_button_bg_hover_color', models.CharField(blank=True, default='#ccc', max_length=20, null=True)),
                ('alert_message_color', models.CharField(blank=True, default='#333', max_length=20, null=True)),
                ('alert_message_bg_color', models.CharField(blank=True, default='#dfd', max_length=20, null=True)),
                ('error_alert_message_color', models.CharField(blank=True, default='#333', max_length=20, null=True)),
                ('error_alert_message_bg_color', models.CharField(blank=True, default='#ffefef', max_length=20, null=True)),
                ('warning_alert_message_color', models.CharField(blank=True, default='#333', max_length=20, null=True)),
                ('warning_alert_message_bg_color', models.CharField(blank=True, default='#ffc', max_length=20, null=True)),
            ],
            options={
                'verbose_name_plural': 'Settings UI',
            },
        ),
    ]



from django import forms


class ModelExampleForm(forms.ModelForm):
    occupation = forms.ChoiceField(choices=[
        ('study', 'Study'),
        ('work', 'Work')
    ], )
    study = forms.CharField(label='Name Institution', required=False,
                            widget=forms.TextInput(attrs={'class': "occupation j__study"}))
    semester = forms.CharField(label='Semester', required=False,
                               widget=forms.TextInput(attrs={'class': "occupation j__study"}))
    company = forms.CharField(required=False,
                              widget=forms.TextInput(attrs={'class': "occupation j__work"}))
    position = forms.CharField(required=False,
                               widget=forms.TextInput(attrs={'class': "occupation j__work"}))

    nick = forms.BooleanField(required=False, label='Add NickName?', help_text='Select if you want to add NickName',
                              widget=forms.CheckboxInput())
    nickname = forms.CharField(required=False, widget=forms.TextInput(attrs={'class': "j__nick"}))


class ThemeUIForm(forms.ModelForm):
    body_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#333333'}))
    header_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#FFFFCC'}))
    header_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#417690'}))
    breadcrumbs_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#C4DCE8'}))
    breadcrumbs_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#79AEC8'}))
    module_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#FFFFFF'}))
    module_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#79EAC8'}))
    sidebar_current_model_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#FFFFCC'}))
    section_link_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#FFFFCC'}))
    link_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#447E9B'}))
    link_hover_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#003366'}))
    section_link_visited_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#FFFFCC'}))
    sidebar_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#FFFFCC'}))
    content_related_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#F8F8F8'}))
    content_related_title_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#333333'}))
    content_related_sub_title_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#666666'}))
    quiet_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#999999'}))
    button_tools_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#FFFFFF'}))
    button_tools_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#999999'}))
    button_tools_hover_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#FFFFFF'}))
    button_tools_hover_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#417690'}))
    th_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#666666'}))
    th_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#F6F6F6'}))
    tr_even_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#F9F9F9'}))
    paginator_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#666666'}))
    paginator_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#FFFFFF'}))
    paginator_border_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#EEEEEE'}))
    submit_delete_button_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#FFFFFF'}))
    submit_delete_button_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#BA2121'}))
    submit_delete_button_bg_hover_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#A41515'}))
    submit_save_primary_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#FFFFFF'}))
    submit_save_primary_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#417690'}))
    submit_save_primary_bg_hover_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#205067'}))
    submit_save_secondary_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#FFFFFF'}))
    submit_save_secondary_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#79EAC8'}))
    submit_save_secondary_bg_hover_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#609AB6'}))
    cancel_button_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#333333'}))
    cancel_button_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#DDDDDD'}))
    cancel_button_bg_hover_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#CCCCCC'}))
    alert_message_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#333333'}))
    alert_message_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#DDFFDD'}))
    error_alert_message_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#333333'}))
    error_alert_message_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#FFEFEF'}))
    warning_alert_message_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#333333'}))
    warning_alert_message_bg_color = forms.CharField(widget=forms.TextInput({'type': 'color', 'value': '#FFFFCC'}))



from django.db import models


class ModelExample(models.Model):
    name = models.CharField(max_length=30)
    occupation = models.CharField(max_length=100, choices=[
        ('study', 'Study'),
        ('work', 'Work')
    ], verbose_name='Occupation')
    study = models.CharField(max_length=100, verbose_name='Name Institution', null=True, blank=True)
    semester = models.CharField(max_length=100, verbose_name='Semester', null=True, blank=True)
    company = models.CharField(max_length=100, verbose_name='Company', null=True, blank=True)
    position = models.CharField(max_length=100, verbose_name='Position', null=True, blank=True)
    nick = models.BooleanField(verbose_name='Add NickName', null=True, blank=True, default=True)
    nickname = models.CharField(max_length=100, verbose_name='Nick Name', null=True, blank=True)

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = 'Model Example'
        verbose_name_plural = 'Model Example'


class ThemeUI(models.Model):
    name_theme = models.CharField(max_length=200, default='')
    applied = models.BooleanField(help_text='If you select this, the previously applied theme is inactivated, '
                                            'if there is none selected by default, the one from django remains')
    title_window = models.CharField(max_length=200, default='')
    site_name = models.CharField(max_length=200, default='')
    body_color = models.CharField(max_length=20, null=True, blank=True, default='#333')
    header_color = models.CharField(max_length=20, null=True, blank=True, default='#ffc')
    header_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#417690')
    breadcrumbs_color = models.CharField(max_length=20, null=True, blank=True, default='#c4dce8')
    breadcrumbs_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#79aec8')
    module_color = models.CharField(max_length=20, null=True, blank=True, default='#fff')
    module_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#79aec8')
    sidebar_current_model_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#ffc')
    section_link_color = models.CharField(max_length=20, null=True, blank=True, default='#ffc')
    link_color = models.CharField(max_length=20, null=True, blank=True, default='#447e9b')
    link_hover_color = models.CharField(max_length=20, null=True, blank=True, default='#036')
    section_link_visited_color = models.CharField(max_length=20, null=True, blank=True, default='#ffc')
    sidebar_color = models.CharField(max_length=20, null=True, blank=True, default='#ffc')
    content_related_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#f8f8f8')
    content_related_title_color = models.CharField(max_length=20, null=True, blank=True, default='#333')
    content_related_sub_title_color = models.CharField(max_length=20, null=True, blank=True, default='#666')
    quiet_color = models.CharField(max_length=20, null=True, blank=True, default='#999')
    button_tools_color = models.CharField(max_length=20, null=True, blank=True, default='#fff')
    button_tools_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#999')
    button_tools_hover_color = models.CharField(max_length=20, null=True, blank=True, default='#fff')
    button_tools_hover_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#417690')
    th_color = models.CharField(max_length=20, null=True, blank=True, default='#666')
    th_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#f6f6f6')
    tr_even_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#f9f9f9')
    paginator_color = models.CharField(max_length=20, null=True, blank=True, default='#666')
    paginator_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#fff')
    paginator_border_color = models.CharField(max_length=20, null=True, blank=True, default='#eee')
    submit_delete_button_color = models.CharField(max_length=20, null=True, blank=True, default='#fff')
    submit_delete_button_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#ba2121')
    submit_delete_button_bg_hover_color = models.CharField(max_length=20, null=True, blank=True, default='#a41515')
    submit_save_primary_color = models.CharField(max_length=20, null=True, blank=True, default='#fff')
    submit_save_primary_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#417690')
    submit_save_primary_bg_hover_color = models.CharField(max_length=20, null=True, blank=True, default='#205067')
    submit_save_secondary_color = models.CharField(max_length=20, null=True, blank=True, default='#fff')
    submit_save_secondary_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#79aec8')
    submit_save_secondary_bg_hover_color = models.CharField(max_length=20, null=True, blank=True, default='#609ab6')
    cancel_button_color = models.CharField(max_length=20, null=True, blank=True, default='#333')
    cancel_button_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#ddd')
    cancel_button_bg_hover_color = models.CharField(max_length=20, null=True, blank=True, default='#ccc')
    alert_message_color = models.CharField(max_length=20, null=True, blank=True, default='#333')
    alert_message_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#dfd')
    error_alert_message_color = models.CharField(max_length=20, null=True, blank=True, default='#333')
    error_alert_message_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#ffefef')
    warning_alert_message_color = models.CharField(max_length=20, null=True, blank=True, default='#333')
    warning_alert_message_bg_color = models.CharField(max_length=20, null=True, blank=True, default='#ffc')

    def __str__(self):
        return self.name_theme

    class Meta:
        verbose_name = 'Theme UI admin'
        verbose_name_plural = 'Theme UI admin'



from setuptools import setup

import os

__version__ = '1.1.1'

gitlab_url = 'https://gitlab.com/florezjose'
package_name = 'django_ui'
package_url = '{}/{}'.format(gitlab_url, package_name)
package_path = os.path.abspath(os.path.dirname(__file__))
long_description_file_path = os.path.join(package_path, 'README.md')
long_description_content_type = 'text/markdown'
long_description = ''
try:
    with open(long_description_file_path) as f:
        long_description = f.read()
except IOError:
    pass


setup(
    name=package_name,
    version=__version__,
    packages=['django_ui'],
    include_package_data=True,
    description='Dynamic fields and settings theme color admin',
    long_description=long_description,
    long_description_content_type=long_description_content_type,
    author='Jose Flórez (@rojosefo)',
    author_email='florezjoserdolfo@gmail.com',
    url=package_url,
    download_url='{}/archive/{}.tar.gz'.format(package_url, __version__),
    keywords=['django', 'fields', 'dynamic', 'theme', 'color',
              'checkbox', 'boolean', 'choices', 'chooser', 'admin', 'python'],
    requires=[
        "django(>=3.0)"
    ],
    install_requires=[
        "Django>=3.0"
    ],
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 3.0',
        'Framework :: Django :: 3.1',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Software Development :: Build Tools',
    ],
)
